### Name: tableContinuous
### Title: Generate a LaTeX table of descriptive statistics for continuous
###   variables
### Aliases: tableContinuous
### Keywords: manip character

### ** Examples

set.seed(1977)
nams <- c("Var1", "Var2")
group <- sample(c(rep("A", 50), rep("B", 50)))
weights <- c(rep(1, 70), rep(0, 10), rep(2, 20))

## display default statistics, provide neither group nor weights
vars <- list(rnorm(20), rgamma(100, 2, 1))
tableContinuous(vars = vars, nams = nams, weights = NA, subset = NA, group = NA, 
    stats = c("n", "min", "q1", "mean", "median", "q3", "max", "iqr", "na"), 
    prec = 1, col.tit = NA, print.pval = "kruskal", 
    cap = "Table of continuous variables.", lab = "tab: descr stat")

## display default statistics, only use a subset of observations, grouped analysis
vars <- list(rnorm(100), rgamma(100, 2, 1))
tableContinuous(vars = vars, nams = nams, weights = weights, subset = 
    c(rep(TRUE, 57), rep(FALSE, 100 - 57)), group = group, stats = 
    c("n", "min", "q1", "mean", "median", "q3", "max", "iqr", "na"), 
    prec = 1, col.tit = NA, print.pval = "kruskal", 
    cap = "Table of continuous variables.", lab = "tab: descr stat")

## supply user-defined statistics: trimmed mean and IQR as an unbiased estimate 
## of the population standard deviation in case of normal data
my.stats <- list("n", "mean", "$\bar{x}_{trim}$" = function(x){return(mean(x, 
    trim = .05))}, "iqr", "IQR.unbiased" = function(x){return(IQR(x) / 
    (2 * qnorm(3 / 4)))})
tableContinuous(vars, nams, weights = weights, group = group, stats = my.stats, 
    prec = 1, col.tit = NA, print.pval = "kruskal", cap = 
    "Table of continuous variables.", lab = "tab: descr stat")

## disp.cols can still be used, for backward compatibility
tableContinuous(vars, nams, subset = rep(TRUE, 40), group = group, disp.cols = 
    c("n", "min", "median", "max", "iqr", "na"), prec = 1, col.tit = NA, 
    print.pval = "kruskal", cap = "Table of continuous variables.", lab = 
    "tab: descr stat")



